@@ -384,7 +384,7 @@ init_scene_Video(AWallpaperPlugin *desktop_plugin)
 void
 init_scene_Slideshow(AWallpaperPlugin *desktop_plugin)
 {
-	gchar *ext, *file, *str;
+	gchar *ext, *file, *str, *bgfile;
 	Dirent  *dp;
 	DIR     *dir_fd;
 	int i;
@@ -423,6 +423,13 @@ init_scene_Slideshow(AWallpaperPlugin *desktop_plugin)
 		}
 		closedir(dir_fd);
 	}
+    
+    bgfile = g_strdup_printf("/home/user/.backgrounds/background-%i.png", desktop_plugin->priv->view);
+    actor = init_object(desktop_plugin, "original", bgfile,
+                      0, 0, 0, 800, 480,
+                      TRUE, TRUE, 100, 255,
+                      NULL, NULL, NULL);
+    scene->actors = g_slist_append(scene->actors, actor);
 
 	child = g_ptr_array_sized_new(num);
 	while (store){
