@@ -338,7 +338,7 @@ fill_theme_button (Animation_WallpaperPrivate *priv, GtkWidget *button, gchar *c
         if (!g_hash_table_lookup(store->data, "category"))
             continue;
         if (!strcmp(g_hash_table_lookup(store->data, "category"), category)){
-            hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector), g_hash_table_lookup(store->data, "name"));
+            hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector), _(g_hash_table_lookup(store->data, "name")));
             if (!strcmp(theme, g_hash_table_lookup(store->data, "name"))){
                 hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR (selector), 0, num);
                 hildon_button_set_value(HILDON_BUTTON(button), _(g_hash_table_lookup(store->data, "name")));
